@@ -1,6 +1,5 @@
 """Contain the main function of bronotes."""
 import argparse
-import shtab
 from bronotes.config import cfg
 from bronotes.actions.add import ActionAdd
 from bronotes.actions.rm import ActionDel
@@ -9,6 +8,20 @@ from bronotes.actions.list import ActionList
 from bronotes.actions.mv import ActionMove
 from bronotes.actions.set import ActionSet
 from bronotes.actions.completions import ActionCompletions
+from bronotes.actions.show import ActionShow
+from bronotes.actions.sync import ActionSync
+
+actions = [
+    ActionAdd(cfg),
+    ActionDel(cfg),
+    ActionList(cfg),
+    ActionEdit(cfg),
+    ActionMove(cfg),
+    ActionSet(cfg),
+    ActionCompletions(cfg),
+    ActionShow(cfg),
+    ActionSync(cfg),
+]
 
 
 def add_arguments(subparser, action):
@@ -51,17 +64,9 @@ def add_subparser(subparsers, action):
 def get_main_parser():
     """Get the main parser."""
     cfg.init()
-    actions = [
-        ActionAdd(cfg),
-        ActionDel(cfg),
-        ActionList(cfg),
-        ActionEdit(cfg),
-        ActionMove(cfg),
-        ActionSet(cfg),
-        ActionCompletions(cfg),
-    ]
     parser = argparse.ArgumentParser(prog='bnote')
-    subparsers = parser.add_subparsers(help='Bronote actions.')
+    subparsers = parser.add_subparsers(
+        help='Bronote actions.', metavar='action')
 
     for action in actions:
         add_subparser(subparsers, action)
@@ -81,6 +86,7 @@ def main():
         args.dir = ''
 
     args.action.init(args)
+
     if args.action.action == 'completions':
         print(args.action.process(parser))
     else:
