@@ -16,20 +16,36 @@ class ActionEdit(BronoteAction):
             'nargs': None
         }
     }
-    flags = {}
+    flags = {
+        '--search': {
+            'short': '-s',
+            'action': 'store_true',
+            'help': 'Search for a file instead of using a hard path.'
+        }
+    }
 
     def init(self, args):
         """Construct the action."""
-        if args.file:
+        if not args.search:
             self.path = Path(os.path.join(
                 self.cfg.dir, args.file))
         else:
-            self.path = False
+            self.path = self.find_note(args.file)
 
     def process(self):
         """Process the action."""
+        if self.path is None:
+            return Text.E_NO_SUCH.value
+
+        if not os.path.isfile(self.path):
+            search_result = self.find_note(self.path.name)
+            if search_result:
+                self.path = search_result
+
         try:
             os.system(f"{os.getenv('EDITOR')} {self.path}")
+            if self.cfg.autosync:
+                self.sync()
             return Text.I_EDIT_FINISHED.value
         except Exception as exc:
             logging.error(exc)
